Release history
===============

.. currentmodule:: sniffio

.. towncrier release notes start

Sniffio 1.3.1 (2024-02-26)
--------------------------

Bugfixes
~~~~~~~~

- Added missing ``thread_local`` to ``sniffio.__all__`` (`#44 <https://github.com/python-trio/sniffio/issues/44>`__)


sniffio 1.3.0 (2022-09-01)
--------------------------

Features
~~~~~~~~

- Add support for Python 3.9 and 3.10. (`#29 <https://github.com/python-trio/sniffio/pull/29>`__)
- Provide ``sniffio.thread_local.name`` for coroutine libraries to set (`#23 <https://github.com/python-trio/sniffio/pull/23>`__)


Deprecations and Removals
~~~~~~~~~~~~~~~~~~~~~~~~~

- Drop support for Python 3.5 and 3.6. (`#29 <https://github.com/python-trio/sniffio/pull/29>`__)


sniffio 1.2.0 (2020-10-11)
--------------------------

Features
~~~~~~~~

- Include type hints (`#17 <https://github.com/python-trio/sniffio/pull/17>`__)


sniffio 1.1.0 (2019-04-19)
--------------------------

Features
~~~~~~~~

- Sniff for curio. (`#5 <https://github.com/python-trio/sniffio/issues/5>`__)


sniffio 1.0.0 (2018-07-31)
--------------------------

Initial release.
